![alt text](images/banner.png "Title")


[![MIT License](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
> [!WARNING]
> This module is in beta phase

#### See the [Wiki](https://github.com/Dhaiven/BetterMaths/wiki) for documentations

## Contribution
BetterMaths accepts community contributions!

## Authors
  - <img src="https://www.github.com/Dhaiven.png" width="3%" height="3%"/> [@Dhaiven](https://www.github.com/Dhaiven) for code
  - <img src="https://www.github.com/algorythmTTV.png" width="3%" height="3%"/> [@algorythmTTV](https://www.github.com/algorythmTTV) for images and site
